@@ -1,7 +1,7 @@
 /*--------------------------------*-C-*---------------------------------*
  * File:	main.c
  *----------------------------------------------------------------------*
- * $Id: main.c,v 1.170.2.1 2002/10/10 05:20:10 gcw Exp $
+ * $Id: main.c,v 1.173 2003/03/28 01:41:11 gcw Exp $
  *
  * All portions of code are copyright by their respective author/s.
  * Copyright (c) 1992      John Bovey, University of Kent at Canterbury <jdb@ukc.ac.uk>
@@ -712,13 +712,12 @@ rxvt_change_font(rxvt_t *r, int init, const char *fontname)
     r->TermWin.mfont = xfont;
 
     if (recheckfonts)
-	/* XXX: This checks what? */
 	if (r->TermWin.mfont != NULL) {
 	    fw = rxvt_get_fontwidest(r->TermWin.mfont);
 	    fh = r->TermWin.mfont->ascent + r->TermWin.mfont->descent;
 	    if (fw > (r->TermWin.fwidth * 2) || fh > r->TermWin.fheight)
 		r->TermWin.mfont = NULL;
-	    if (fw == r->TermWin.fwidth /* && fh == r->TermWin.fheight */ )
+	    if (fw == (r->TermWin.fwidth * 2) /* && fh==r->TermWin.fheight */ )
 		r->TermWin.propfont &= ~PROPFONT_MULTI;
 	    else
 		r->TermWin.propfont |= PROPFONT_MULTI;
@@ -889,7 +888,7 @@ rxvt_set_window_color(rxvt_t *r, int idx, const char *color)
     rxvt_set_colorfgbg(r);
     rxvt_recolour_cursor(r);
 /* the only reasonable way to enforce a clean update */
-    rxvt_scr_touch(r, False);
+    rxvt_scr_poweron(r);
 }
 
 #else
